# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'StackV1StackOutputArgs',
]

@pulumi.input_type
class StackV1StackOutputArgs:
    def __init__(__self__, *,
                 output_key: pulumi.Input[str],
                 output_value: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] description: The description of the stack resource.
        """
        pulumi.set(__self__, "output_key", output_key)
        pulumi.set(__self__, "output_value", output_value)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @property
    @pulumi.getter(name="outputKey")
    def output_key(self) -> pulumi.Input[str]:
        return pulumi.get(self, "output_key")

    @output_key.setter
    def output_key(self, value: pulumi.Input[str]):
        pulumi.set(self, "output_key", value)

    @property
    @pulumi.getter(name="outputValue")
    def output_value(self) -> pulumi.Input[str]:
        return pulumi.get(self, "output_value")

    @output_value.setter
    def output_value(self, value: pulumi.Input[str]):
        pulumi.set(self, "output_value", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the stack resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)


